event_file library
Classes
- FileRepository
- Repository that manages saving and loading files.
- FileTypeRepository
- Checks the type of a file based on the bytes
- LocalFileRepository
- Implementation of FileRepository that saves and loads the files from the local directory.